@@ -39,6 +39,8 @@ sub template {
   			INCLUDE_PATH => [ $post_template_root, catdir($post_template_root, 'include') ],
   			INTERPOLATE  => 1,
         ENCODING => 'utf8',
+        START_TAG => quotemeta('{{'),
+        END_TAG   => quotemeta('}}'),
   		}) || die "$Template::ERROR\n";
 
     my $vars = {
@@ -75,17 +77,17 @@ sub template {
     $vars->{URL} =~ s"/$""g;
 
     $vars->{ROOT} =~ s"^http:/+"/"g;
-    $vars->{ROOT} = "/" . $vars->{ROOT};
+    $vars->{ROOT} = "/" . $vars->{ROOT} if $vars->{ROOT} !~ m:^/:;
     $vars->{ROOT} =~ s"/+"/"g;
-    $vars->{ROOT} =~ s"/$""g;
+    $vars->{ROOT} =~ s"/$""g unless $vars->{ROOT} eq "/";
 
     $vars->{FloorURL} =~ s"(?<!http:)/+"/"g;
     $vars->{FloorURL} =~ s"/$""g;
 
     $vars->{FloorROOT} =~ s"^http:/+"/"g;
-    $vars->{FloorROOT} = "/" . $vars->{FloorROOT};
+    $vars->{FloorROOT} = "/" . $vars->{FloorROOT} if $vars->{FloorROOT} !~ m:^/:;
     $vars->{FloorROOT} =~ s"/+"/"g;
-    $vars->{FloorROOT} =~ s"/$""g;
+    $vars->{FloorROOT} =~ s"/$""g unless $vars->{FloorROOT} eq "/";
 
     my $posts = [];
     push @$posts, $allentries->{$utid};
